@@ -67,9 +67,12 @@ def stop():
 def setup(testobj):
     """Test setup."""
     # Make sure future statements in our doctests are the same as everywhere
-    # else.
-    testobj.globs['absolute_import'] = absolute_import
-    testobj.globs['unicode_literals'] = unicode_literals
+    # else.  Note however that 2to3 "fixes" this module by undefining these
+    # unnecessary (but still present) future imports.
+    if 'absolute_import' in dir():
+        testobj.globs['absolute_import'] = absolute_import
+    if 'unicode_literals' in dir():
+        testobj.globs['unicode_literals'] = unicode_literals
     testobj.globs['stop'] = stop
 
 
